import { ChildProcess, fork } from 'child_process';

export const runProcess = (appPath: string) => {
  const process = fork(appPath);
  process.on('exit', (code) => {
    console.log(`Process exited with code ${code}`);
  });

  process.on('message', (message) => {
    console.log('Message from child:', message);
  });

  // Example of sending a message to the child process
  // process.send({ hello: 'world' });
};
class BaseProcess {
  private process: ChildProcess;
  status: 'running' | 'stopped' | 'error' = 'stopped';
  appPath: string;
  constructor(appPath: string) {
    this.appPath = appPath;
    // this.createProcess(appPath);
  }
  createProcess(appPath: string = this.appPath) {
    if (this.process) {
      this.process.kill();
    }
    this.appPath = appPath;
    this.process = fork(appPath);
    return this;
  }
  kill(signal?: NodeJS.Signals | number) {
    if (this.process) {
      this.process.kill(signal);
    }
    return this;
  }
  public send(message: any) {
    this.process.send(message);
  }

  public on(event: string, callback: (message: any) => void) {
    this.process.on(event, callback);
  }

  public onExit(callback: (code: number) => void) {
    this.process.on('exit', callback);
  }

  public onError(callback: (error: Error) => void) {
    this.process.on('error', callback);
  }

  public onMessage(callback: (message: any) => void) {
    this.process.on('message', callback);
  }

  public onClose(callback: () => void) {
    this.process.on('close', callback);
  }

  public onDisconnect(callback: () => void) {
    this.process.on('disconnect', callback);
  }
}
export class AssistantProcess extends BaseProcess {
  constructor(appPath: string) {
    super(appPath);
  }
}
