import http from 'http';
import send from 'send';
import fs from 'fs';
import { fileIsExist } from '@kevisual/use-config';
import path from 'path';
import { ProxyInfo } from './proxy.ts';

export const fileProxy = (req: http.IncomingMessage, res: http.ServerResponse, proxyApi: ProxyInfo) => {
  // url开头的文件
  const url = new URL(req.url, 'http://localhost');
  let pathname = url.pathname.slice(1);
  const { indexPath = '', target = '', rootPath = process.cwd() } = proxyApi;
  try {
    if (pathname.endsWith('/')) {
      pathname = pathname + 'index.html';
    }
    // 检测文件是否存在，如果文件不存在，则返回404
    let filePath = path.join(rootPath, target, pathname);
    let exist = fileIsExist(filePath);
    if (!exist) {
      filePath = path.join(rootPath, target, '/' + indexPath);
      exist = fileIsExist(filePath);
    }
    console.log('filePath', filePath, exist);
    
    if (!exist) {
      res.statusCode = 404;
      res.end('Not Found File');
      return;
    }
    const ext = path.extname(filePath);
    let maxAge = 24 * 60 * 60 * 1000; // 24小时
    if (ext === '.html') {
      maxAge = 0;
    }
    let sendFilePath = filePath.replace(rootPath + '/', '');
    const file = send(req, sendFilePath, {
      root: rootPath,
      maxAge,
    });
    file.pipe(res);
  } catch (error) {
    res.statusCode = 404;
    res.end('Error:Not Found File');
    return;
  }
};
