import { fileProxy, apiProxy, createApiProxy } from '@kevisual/assistant-module/proxy';
import { getCacheAssistantConfig, appDir } from '@kevisual/assistant-module';
import http from 'http';

// https://localhost:51015/user/tiptap/
export const proxyRoute = async (req: http.IncomingMessage, res: http.ServerResponse) => {
  const assistantConfig = getCacheAssistantConfig();
  // const { apiList } = assistantConfig;
  const url = new URL(req.url, 'http://localhost');
  const pathname = url.pathname;
  if (pathname.startsWith('/favicon.ico')) {
    res.statusCode = 404;
    res.end('Not Found Favicon');
    return;
  }
  if (pathname.startsWith('/client')) {
    console.log('handle by router');
    return;
  }
  const apiProxyList = assistantConfig?.apiProxyList || [];
  const defaultApiProxy = createApiProxy(assistantConfig?.pageApi || 'https://kevisual.xiongxiao.me');
  const apiBackendProxy = [...apiProxyList, ...defaultApiProxy].find((item) => pathname.startsWith(item.path));
  if (apiBackendProxy) {
    console.log('apiBackendProxy', apiBackendProxy);
    return apiProxy(req, res, {
      path: apiBackendProxy.path,
      target: apiBackendProxy.target,
    });
  }
  // client, api, v1, serve 开头的拦截
  const proxyApiList = assistantConfig?.proxy || [];
  const proxyApi = proxyApiList.find((item) => pathname.startsWith(item.path));
  if (proxyApi) {
    console.log('proxyApi', proxyApi, pathname);
    const { user, key } = proxyApi;
    return fileProxy(req, res, {
      path: proxyApi.path,
      rootPath: appDir,
      indexPath: `${user}/${key}/index.html`,
    });
  }
  const localProxyProxy = localProxyProxyList.find((item) => pathname.startsWith(item.path));
  if (localProxyProxy) {
    return fileProxy(req, res, {
      path: localProxyProxy.path,
      rootPath: process.cwd(),
      indexPath: localProxyProxy.indexPath,
    });
  }
  console.log('handle by router 404');
  res.statusCode = 404;
  res.end('Not Found Proxy');
};
const localProxyProxyList = [
  {
    user: 'root',
    key: 'assistant-base-app',
    path: '/root/assistant-base-app',
    indexPath: 'root/assistant-base-app/index.html',
  },
];
